<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// S
	'stats_description' => 'SPIP Statistiken',
	'stats_nom' => 'Statistiken',
	'stats_slogan' => 'Verwlatung der SPIIP-Statistiken',
];
